# 2048
2048 Clone written in Python. <br>

To install, run `pip install py2048-coolin`. <br>
To execute, type `2048` and hit enter. If you haven't started the game before, it will download a font to your user data directory and make a `.json` save file there. <br>

Available on <a href="https://pypi.org/project/py2048-coolin/">PyPI</a>
